# coding: utf-8

"""
    Amber API Server

    Boon Logic Amber API server

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class MNanoBackend(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'version_number': 'VersionNumber',
        'm_pattern_memory': 'MPatternMemory',
        'm_init_complete': 'bool',
        'm_pattern_length': 'float',
        'm_learning_is_on': 'bool',
        'm_num_of_patterns_clustered': 'float'
    }

    attribute_map = {
        'version_number': 'versionNumber',
        'm_pattern_memory': 'm_PatternMemory',
        'm_init_complete': 'm_InitComplete',
        'm_pattern_length': 'm_PatternLength',
        'm_learning_is_on': 'm_LearningIsOn',
        'm_num_of_patterns_clustered': 'm_NumOfPatternsClustered'
    }

    def __init__(self, version_number=None, m_pattern_memory=None, m_init_complete=None, m_pattern_length=None, m_learning_is_on=None, m_num_of_patterns_clustered=None):
        """MNanoBackend - a model defined in Swagger"""
        self._version_number = None
        self._m_pattern_memory = None
        self._m_init_complete = None
        self._m_pattern_length = None
        self._m_learning_is_on = None
        self._m_num_of_patterns_clustered = None
        self.discriminator = None
        if version_number is not None:
            self.version_number = version_number
        if m_pattern_memory is not None:
            self.m_pattern_memory = m_pattern_memory
        if m_init_complete is not None:
            self.m_init_complete = m_init_complete
        if m_pattern_length is not None:
            self.m_pattern_length = m_pattern_length
        if m_learning_is_on is not None:
            self.m_learning_is_on = m_learning_is_on
        if m_num_of_patterns_clustered is not None:
            self.m_num_of_patterns_clustered = m_num_of_patterns_clustered

    @property
    def version_number(self):
        """Gets the version_number of this MNanoBackend.


        :return: The version_number of this MNanoBackend.
        :rtype: VersionNumber
        """
        return self._version_number

    @version_number.setter
    def version_number(self, version_number):
        """Sets the version_number of this MNanoBackend.


        :param version_number: The version_number of this MNanoBackend.
        :type: VersionNumber
        """

        self._version_number = version_number

    @property
    def m_pattern_memory(self):
        """Gets the m_pattern_memory of this MNanoBackend.


        :return: The m_pattern_memory of this MNanoBackend.
        :rtype: MPatternMemory
        """
        return self._m_pattern_memory

    @m_pattern_memory.setter
    def m_pattern_memory(self, m_pattern_memory):
        """Sets the m_pattern_memory of this MNanoBackend.


        :param m_pattern_memory: The m_pattern_memory of this MNanoBackend.
        :type: MPatternMemory
        """

        self._m_pattern_memory = m_pattern_memory

    @property
    def m_init_complete(self):
        """Gets the m_init_complete of this MNanoBackend.


        :return: The m_init_complete of this MNanoBackend.
        :rtype: bool
        """
        return self._m_init_complete

    @m_init_complete.setter
    def m_init_complete(self, m_init_complete):
        """Sets the m_init_complete of this MNanoBackend.


        :param m_init_complete: The m_init_complete of this MNanoBackend.
        :type: bool
        """

        self._m_init_complete = m_init_complete

    @property
    def m_pattern_length(self):
        """Gets the m_pattern_length of this MNanoBackend.


        :return: The m_pattern_length of this MNanoBackend.
        :rtype: float
        """
        return self._m_pattern_length

    @m_pattern_length.setter
    def m_pattern_length(self, m_pattern_length):
        """Sets the m_pattern_length of this MNanoBackend.


        :param m_pattern_length: The m_pattern_length of this MNanoBackend.
        :type: float
        """

        self._m_pattern_length = m_pattern_length

    @property
    def m_learning_is_on(self):
        """Gets the m_learning_is_on of this MNanoBackend.


        :return: The m_learning_is_on of this MNanoBackend.
        :rtype: bool
        """
        return self._m_learning_is_on

    @m_learning_is_on.setter
    def m_learning_is_on(self, m_learning_is_on):
        """Sets the m_learning_is_on of this MNanoBackend.


        :param m_learning_is_on: The m_learning_is_on of this MNanoBackend.
        :type: bool
        """

        self._m_learning_is_on = m_learning_is_on

    @property
    def m_num_of_patterns_clustered(self):
        """Gets the m_num_of_patterns_clustered of this MNanoBackend.


        :return: The m_num_of_patterns_clustered of this MNanoBackend.
        :rtype: float
        """
        return self._m_num_of_patterns_clustered

    @m_num_of_patterns_clustered.setter
    def m_num_of_patterns_clustered(self, m_num_of_patterns_clustered):
        """Sets the m_num_of_patterns_clustered of this MNanoBackend.


        :param m_num_of_patterns_clustered: The m_num_of_patterns_clustered of this MNanoBackend.
        :type: float
        """

        self._m_num_of_patterns_clustered = m_num_of_patterns_clustered

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MNanoBackend, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MNanoBackend):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
