# coding: utf-8

"""
    Amber API Server

    Boon Logic Amber API server

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class MNanoConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'version_number': 'VersionNumber',
        'm_numeric_format': 'float',
        'm_accuracy': 'float',
        'm_percent_variation': 'float',
        'num_of_features': 'float',
        'features': 'list[FeatureConfig]'
    }

    attribute_map = {
        'version_number': 'versionNumber',
        'm_numeric_format': 'm_NumericFormat',
        'm_accuracy': 'm_Accuracy',
        'm_percent_variation': 'm_PercentVariation',
        'num_of_features': 'numOfFeatures',
        'features': 'features'
    }

    def __init__(self, version_number=None, m_numeric_format=None, m_accuracy=None, m_percent_variation=None, num_of_features=None, features=None):
        """MNanoConfig - a model defined in Swagger"""
        self._version_number = None
        self._m_numeric_format = None
        self._m_accuracy = None
        self._m_percent_variation = None
        self._num_of_features = None
        self._features = None
        self.discriminator = None
        if version_number is not None:
            self.version_number = version_number
        if m_numeric_format is not None:
            self.m_numeric_format = m_numeric_format
        if m_accuracy is not None:
            self.m_accuracy = m_accuracy
        self.m_percent_variation = m_percent_variation
        self.num_of_features = num_of_features
        self.features = features

    @property
    def version_number(self):
        """Gets the version_number of this MNanoConfig.


        :return: The version_number of this MNanoConfig.
        :rtype: VersionNumber
        """
        return self._version_number

    @version_number.setter
    def version_number(self, version_number):
        """Sets the version_number of this MNanoConfig.


        :param version_number: The version_number of this MNanoConfig.
        :type: VersionNumber
        """

        self._version_number = version_number

    @property
    def m_numeric_format(self):
        """Gets the m_numeric_format of this MNanoConfig.


        :return: The m_numeric_format of this MNanoConfig.
        :rtype: float
        """
        return self._m_numeric_format

    @m_numeric_format.setter
    def m_numeric_format(self, m_numeric_format):
        """Sets the m_numeric_format of this MNanoConfig.


        :param m_numeric_format: The m_numeric_format of this MNanoConfig.
        :type: float
        """

        self._m_numeric_format = m_numeric_format

    @property
    def m_accuracy(self):
        """Gets the m_accuracy of this MNanoConfig.


        :return: The m_accuracy of this MNanoConfig.
        :rtype: float
        """
        return self._m_accuracy

    @m_accuracy.setter
    def m_accuracy(self, m_accuracy):
        """Sets the m_accuracy of this MNanoConfig.


        :param m_accuracy: The m_accuracy of this MNanoConfig.
        :type: float
        """

        self._m_accuracy = m_accuracy

    @property
    def m_percent_variation(self):
        """Gets the m_percent_variation of this MNanoConfig.

        the percent variation (for instance 0.025 gives 2.5% variation) used for clustering

        :return: The m_percent_variation of this MNanoConfig.
        :rtype: float
        """
        return self._m_percent_variation

    @m_percent_variation.setter
    def m_percent_variation(self, m_percent_variation):
        """Sets the m_percent_variation of this MNanoConfig.

        the percent variation (for instance 0.025 gives 2.5% variation) used for clustering

        :param m_percent_variation: The m_percent_variation of this MNanoConfig.
        :type: float
        """
        if m_percent_variation is None:
            raise ValueError("Invalid value for `m_percent_variation`, must not be `None`")

        self._m_percent_variation = m_percent_variation

    @property
    def num_of_features(self):
        """Gets the num_of_features of this MNanoConfig.


        :return: The num_of_features of this MNanoConfig.
        :rtype: float
        """
        return self._num_of_features

    @num_of_features.setter
    def num_of_features(self, num_of_features):
        """Sets the num_of_features of this MNanoConfig.


        :param num_of_features: The num_of_features of this MNanoConfig.
        :type: float
        """
        if num_of_features is None:
            raise ValueError("Invalid value for `num_of_features`, must not be `None`")

        self._num_of_features = num_of_features

    @property
    def features(self):
        """Gets the features of this MNanoConfig.


        :return: The features of this MNanoConfig.
        :rtype: list[FeatureConfig]
        """
        return self._features

    @features.setter
    def features(self, features):
        """Sets the features of this MNanoConfig.


        :param features: The features of this MNanoConfig.
        :type: list[FeatureConfig]
        """
        if features is None:
            raise ValueError("Invalid value for `features`, must not be `None`")

        self._features = features

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MNanoConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MNanoConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
